package routes

import (
	"PaymentCenter/app/http/controllers"
	"PaymentCenter/app/http/controllers/backend"
	"PaymentCenter/app/http/middlewares"
	"PaymentCenter/app/http/trace"
	"PaymentCenter/app/utils"
	"PaymentCenter/config"
	"github.com/gin-gonic/gin"
	"github.com/qit-team/snow-core/http/middleware"
)

func RegisterAdminRoute(router *gin.Engine) {
	router.Use(middlewares.ServerRecovery(), middleware.GenRequestId, middleware.GenContextKit, middleware.AccessLog())
	router.NoRoute(controllers.Error404)
	if len(config.GetConf().SkyWalkingOapServer) > 0 && config.IsEnvEqual(config.ProdEnv) {
		err := trace.InitTracer(config.GetConf().ServiceName, config.GetConf().SkyWalkingOapServer)
		if err != nil {
			utils.Log(nil, "InitTracer", err.Error())
		} else {
			router.Use(middlewares.Trace())
		}
	}

	v1 := router.Group("/admin/pay/api/v1", middlewares.ValidateRequest())
	{
		// 商户管理
		merchant := v1.Group("/merchant")
		merchant.GET("/list", backend.MerchantList)        // 商户列表
		merchant.POST("/create", backend.MerchantCreate)   // 商户创建
		merchant.PUT("/update", backend.MerchantUpdate)    // 商户更新
		merchant.DELETE("/delete", backend.MerchantDelete) // 商户删除
	}

}
